@@ -115,8 +115,7 @@ func DefaultClient(ctx context.Context) (*Client, error) {
 }
 
 const (
-	timeout = 2 * time.Second
-	cycle   = time.Second / 20
+	cycle = time.Second / 20
 )
 
 type Client struct {
@@ -354,7 +353,6 @@ func (c *Client) WaitForTunnel(parent context.Context, slug string) (err error)
 
 // WaitForDNS waits for a Fly host internal DNS entry to register
 func (c *Client) WaitForDNS(parent context.Context, dialer Dialer, slug string, host string) (err error) {
-
 	io := iostreams.FromContext(parent)
 	io.StartProgressIndicatorMsg(fmt.Sprintf("Waiting for host %s", host))
 	ctx, cancel := context.WithTimeout(parent, 4*time.Minute)
@@ -592,7 +590,7 @@ func (p *Pinger) WriteTo(buf []byte, addr net.Addr) (int64, error) {
 	lbuf := make([]byte, 2)
 	binary.BigEndian.PutUint16(lbuf, uint16(len(buf)))
 
-	_, err = p.c.Write([]byte(lbuf))
+	_, err = p.c.Write(lbuf)
 	if err != nil {
 		p.err = fmt.Errorf("icmp write: length: %w", err)
 		return 0, p.err
