@@ -69,10 +69,13 @@ func (l *Launcher) LaunchMachinesPostgres(ctx context.Context, config *CreateClu
 
 	io := iostreams.FromContext(ctx)
 
-	flaps, err := flaps.New(ctx, app)
+	flapsClient, err := flaps.New(ctx, app)
 	if err != nil {
 		return err
 	}
+	ctx = flaps.NewContext(ctx, flapsClient)
+
+	var nodes = make([]*api.Machine, 0)
 
 	for i := 0; i < config.InitialClusterSize; i++ {
 		machineConf := l.getPostgresConfig(config)
@@ -126,26 +129,34 @@ func (l *Launcher) LaunchMachinesPostgres(ctx context.Context, config *CreateClu
 			Config:  machineConf,
 		}
 
-		machine, err := flaps.Launch(ctx, launchInput)
+		machine, err := flapsClient.Launch(ctx, launchInput)
 		if err != nil {
 			return err
 		}
 
-		fmt.Printf("Waiting for machine to start...")
+		fmt.Fprintf(io.Out, "Waiting for machine to start...\n")
 
 		waitTimeout := time.Minute * 5
 		if snapshot != nil {
 			waitTimeout = time.Hour
 		}
 
-		err = machines.WaitForStartOrStop(ctx, flaps, machine, "start", waitTimeout)
+		err = machines.WaitForStartOrStop(ctx, machine, "start", waitTimeout)
 		if err != nil {
 			return err
 		}
+		nodes = append(nodes, machine)
+
 		fmt.Fprintf(io.Out, "Machine %s is %s\n", machine.ID, machine.State)
 
 	}
 
+	if !flag.GetBool(ctx, "detach") {
+		if err := watch.MachinesChecks(ctx, nodes); err != nil {
+			return err
+		}
+	}
+
 	connStr := fmt.Sprintf("postgres://postgres:%s@%s.internal:5432\n", secrets["OPERATOR_PASSWORD"], config.AppName)
 
 	fmt.Fprintf(io.Out, "  Username:    postgres\n")
