@@ -105,7 +105,9 @@ func runCreate(ctx context.Context) (err error) {
 
 	var region *api.Region
 
-	region, err = prompt.Region(ctx, "")
+	region, err = prompt.Region(ctx, prompt.RegionParams{
+		Message: "",
+	})
 	if err != nil {
 		return
 	}
