@@ -17,6 +17,7 @@ import (
 	machines "github.com/superfly/flyctl/internal/command/machine"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/prompt"
+	"github.com/superfly/flyctl/internal/watch"
 	"github.com/superfly/flyctl/iostreams"
 )
 
@@ -40,6 +41,7 @@ func newUpdate() (cmd *cobra.Command) {
 			Name:        "auto-confirm",
 			Description: "Will automatically confirm changes without an interactive prompt.",
 		},
+		flag.Detach(),
 	)
 
 	return
@@ -200,6 +202,11 @@ func runUpdate(ctx context.Context) error {
 			if err := updateMachine(ctx, app, replica, image); err != nil {
 				return fmt.Errorf("can't update %s: %w", replica.ID, err)
 			}
+
+			// wait for health checks to pass
+			if err := watch.MachinesChecks(ctx, []*api.Machine{replica}); err != nil {
+				return fmt.Errorf("failed to wait for health checks to pass: %w", err)
+			}
 		}
 	}
 
@@ -222,6 +229,11 @@ func runUpdate(ctx context.Context) error {
 		if err := updateMachine(ctx, app, leader, image); err != nil {
 			return err
 		}
+
+		// wait for health checks to pass
+		if err := watch.MachinesChecks(ctx, []*api.Machine{leader}); err != nil {
+			return fmt.Errorf("failed to wait for health checks to pass: %w", err)
+		}
 	}
 
 	fmt.Fprintf(io.Out, "Postgres cluster has been successfully updated!\n")
@@ -230,10 +242,11 @@ func runUpdate(ctx context.Context) error {
 }
 
 func updateMachine(ctx context.Context, app *api.AppCompact, machine *api.Machine, image string) error {
-	flaps, err := flaps.New(ctx, app)
+	flapsClient, err := flaps.New(ctx, app)
 	if err != nil {
 		return err
 	}
+	ctx = flaps.NewContext(ctx, flapsClient)
 
 	machineConf := machine.Config
 	machineConf.Image = image
@@ -246,12 +259,12 @@ func updateMachine(ctx context.Context, app *api.AppCompact, machine *api.Machin
 		Config:  machineConf,
 	}
 
-	updated, err := flaps.Update(ctx, input, machine.LeaseNonce)
+	updated, err := flapsClient.Update(ctx, input, machine.LeaseNonce)
 	if err != nil {
 		return err
 	}
 
-	if err := machines.WaitForStartOrStop(ctx, flaps, updated, "start", time.Minute*5); err != nil {
+	if err := machines.WaitForStartOrStop(ctx, updated, "start", time.Minute*5); err != nil {
 		return err
 	}
 
